@@ -10,32 +10,31 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.14';
-$DATE = '2003/09/15';
+$VERSION = '0.15';
+$DATE = '2003/09/18';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Test_Tech.pm' => [qw(0.14 2003/09/15), 'revised 0.13'],
-    'MANIFEST' => [qw(0.14 2003/09/15), 'generated, replaces 0.13'],
-    'Makefile.PL' => [qw(0.14 2003/09/15), 'generated, replaces 0.13'],
-    'README' => [qw(0.14 2003/09/15), 'generated, replaces 0.13'],
-    'lib/Test/Tech.pm' => [qw(1.13 2003/09/15), 'revised 1.12'],
-    't/Test/Tech/Tech.t' => [qw(0.12 2003/09/15), 'revised 0.11'],
-    't/Test/Tech/techA0.t' => [qw(0.08 2003/09/15), 'revised 0.07'],
-    't/Test/Tech/techA2.txt' => [qw(0.07 2003/09/15), 'revised 0.06'],
-    't/Test/Tech/techB0.t' => [qw(0.05 2003/09/15), 'revised 0.04'],
-    't/Test/Tech/techC0.t' => [qw(0.08 2003/09/15), 'revised 0.07'],
-    't/Test/Tech/techC2.txt' => [qw(0.07 2003/09/15), 'revised 0.06'],
-    't/Test/Tech/techC3.txt' => [qw(0.08 2003/09/15), 'revised 0.07'],
-    't/Test/Tech/techD0.d' => [qw(0.04 2003/09/15), 'revised 0.03'],
-    't/Test/Tech/techD2.txt' => [qw(0.07 2003/09/15), 'revised 0.06'],
-    't/Test/Tech/techD3.txt' => [qw(0.07 2003/09/15), 'revised 0.06'],
-    'tlib/File/Package.pm' => [qw(1.12 2003/09/15), 'revised 1.11'],
-    'tlib/File/SmartNL.pm' => [qw(1.12 2003/09/15), 'revised 1.1'],
-    'tlib/Text/Scrub.pm' => [qw(1.1 2003/09/15), 'revised 1.09'],
-    't/Test/Tech/V001024/Test.pm' => [qw(1.25 2003/09/15), 'revised 1.24'],
-    't/Test/Tech/V001015/Test.pm' => [qw(1.16 2003/09/15), 'revised 1.15'],
+    'lib/Docs/Site_SVD/Test_Tech.pm' => [qw(0.15 2003/09/18), 'revised 0.14'],
+    'MANIFEST' => [qw(0.15 2003/09/18), 'generated, replaces 0.14'],
+    'Makefile.PL' => [qw(0.15 2003/09/18), 'generated, replaces 0.14'],
+    'README' => [qw(0.15 2003/09/18), 'generated, replaces 0.14'],
+    'lib/Test/Tech.pm' => [qw(1.14 2003/09/18), 'revised 1.13'],
+    't/Test/Tech/Tech.t' => [qw(0.13 2003/09/18), 'revised 0.12'],
+    't/Test/Tech/techA0.t' => [qw(0.08 2003/09/15), 'unchanged'],
+    't/Test/Tech/techA2.txt' => [qw(0.07 2003/09/15), 'unchanged'],
+    't/Test/Tech/techB0.t' => [qw(0.05 2003/09/15), 'unchanged'],
+    't/Test/Tech/techC0.t' => [qw(0.09 2003/09/18), 'revised 0.08'],
+    't/Test/Tech/techC2.txt' => [qw(0.08 2003/09/18), 'revised 0.07'],
+    't/Test/Tech/techD0.d' => [qw(0.04 2003/09/15), 'unchanged'],
+    't/Test/Tech/techD2.txt' => [qw(0.07 2003/09/15), 'unchanged'],
+    't/Test/Tech/techD3.txt' => [qw(0.07 2003/09/15), 'unchanged'],
+    'tlib/File/Package.pm' => [qw(1.12 2003/09/18), 'unchanged'],
+    'tlib/File/SmartNL.pm' => [qw(1.12 2003/09/18), 'unchanged'],
+    'tlib/Text/Scrub.pm' => [qw(1.11 2003/09/18), 'revised 1.1'],
+    't/Test/Tech/V001024/Test.pm' => [qw(1.25 2003/09/15), 'unchanged'],
+    't/Test/Tech/V001015/Test.pm' => [qw(1.16 2003/09/15), 'unchanged'],
 
 );
 
@@ -62,11 +61,11 @@ use vars qw(%INVENTORY);
 
  Test::Tech - Extends the Test program module
 
- Revision: L
+ Revision: M
 
- Version: 0.14
+ Version: 0.15
 
- Date: 2003/09/15
+ Date: 2003/09/18
 
  Prepared for: General Public 
 
@@ -133,7 +132,7 @@ session using the methods under test
 
 =head2 1.3 Document overview.
 
-This document releases Test::Tech version 0.14
+This document releases Test::Tech version 0.15
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -149,8 +148,8 @@ system file specification.
 This document releases the file found
 at the following repository(s):
 
-   http://www.softwarediamonds/packages/Test-Tech-0.14
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.14
+   http://www.softwarediamonds/packages/Test-Tech-0.15
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.15
 
 
 Restrictions regarding duplication and license provisions
@@ -218,26 +217,25 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Test_Tech.pm                               0.14    2003/09/15 revised 0.13
- MANIFEST                                                     0.14    2003/09/15 generated, replaces 0.13
- Makefile.PL                                                  0.14    2003/09/15 generated, replaces 0.13
- README                                                       0.14    2003/09/15 generated, replaces 0.13
- lib/Test/Tech.pm                                             1.13    2003/09/15 revised 1.12
- t/Test/Tech/Tech.t                                           0.12    2003/09/15 revised 0.11
- t/Test/Tech/techA0.t                                         0.08    2003/09/15 revised 0.07
- t/Test/Tech/techA2.txt                                       0.07    2003/09/15 revised 0.06
- t/Test/Tech/techB0.t                                         0.05    2003/09/15 revised 0.04
- t/Test/Tech/techC0.t                                         0.08    2003/09/15 revised 0.07
- t/Test/Tech/techC2.txt                                       0.07    2003/09/15 revised 0.06
- t/Test/Tech/techC3.txt                                       0.08    2003/09/15 revised 0.07
- t/Test/Tech/techD0.d                                         0.04    2003/09/15 revised 0.03
- t/Test/Tech/techD2.txt                                       0.07    2003/09/15 revised 0.06
- t/Test/Tech/techD3.txt                                       0.07    2003/09/15 revised 0.06
- tlib/File/Package.pm                                         1.12    2003/09/15 revised 1.11
- tlib/File/SmartNL.pm                                         1.12    2003/09/15 revised 1.1
- tlib/Text/Scrub.pm                                           1.1     2003/09/15 revised 1.09
- t/Test/Tech/V001024/Test.pm                                  1.25    2003/09/15 revised 1.24
- t/Test/Tech/V001015/Test.pm                                  1.16    2003/09/15 revised 1.15
+ lib/Docs/Site_SVD/Test_Tech.pm                               0.15    2003/09/18 revised 0.14
+ MANIFEST                                                     0.15    2003/09/18 generated, replaces 0.14
+ Makefile.PL                                                  0.15    2003/09/18 generated, replaces 0.14
+ README                                                       0.15    2003/09/18 generated, replaces 0.14
+ lib/Test/Tech.pm                                             1.14    2003/09/18 revised 1.13
+ t/Test/Tech/Tech.t                                           0.13    2003/09/18 revised 0.12
+ t/Test/Tech/techA0.t                                         0.08    2003/09/15 unchanged
+ t/Test/Tech/techA2.txt                                       0.07    2003/09/15 unchanged
+ t/Test/Tech/techB0.t                                         0.05    2003/09/15 unchanged
+ t/Test/Tech/techC0.t                                         0.09    2003/09/18 revised 0.08
+ t/Test/Tech/techC2.txt                                       0.08    2003/09/18 revised 0.07
+ t/Test/Tech/techD0.d                                         0.04    2003/09/15 unchanged
+ t/Test/Tech/techD2.txt                                       0.07    2003/09/15 unchanged
+ t/Test/Tech/techD3.txt                                       0.07    2003/09/15 unchanged
+ tlib/File/Package.pm                                         1.12    2003/09/18 unchanged
+ tlib/File/SmartNL.pm                                         1.12    2003/09/18 unchanged
+ tlib/Text/Scrub.pm                                           1.11    2003/09/18 revised 1.1
+ t/Test/Tech/V001024/Test.pm                                  1.25    2003/09/15 unchanged
+ t/Test/Tech/V001015/Test.pm                                  1.16    2003/09/15 unchanged
 
 
 =head2 3.3 Changes
@@ -426,6 +424,19 @@ Use Archive::TarGzip 0.02 that uses mode 777 for directories instead of 666. Sta
 emails from Unix about untar not being able to change to
 a directory with mod of 666.
 
+=item Test-Tech-0.15
+
+Changed from using 'Data::Strify' to 'Data::Secs2' for the stringify function.
+'Data::Secs2' is useful for SEMI clients and also provides sorted hash keys
+required for comparing stringifcation of Perl's nested data.
+The 'Data::Secs2' obsoletes 'Data::Strify' which is history. 
+
+Double checked that PREREQ_PM is 'Data::Secs2' which
+fixes Test-Tech-0.14 error in the PREREQ_PM 
+which errorneous used by 'Data/Strify.pm' instead of 'Data::Strify'.
+This should clear complain by Mike Castle <dalgoda@ix.netcom.com> that
+the MakeFile.PL for Test-Tech-0.14 crashes with a divide by zero.
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -459,13 +470,13 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/Test-Tech-0.14
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.14
+   http://www.softwarediamonds/packages/Test-Tech-0.15
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-Tech-0.15
 
 
 =item Prerequistes.
 
- lib/Data/Strify.pm
+ Data::Secs2 => 0.01
 
 
 =item Security, privacy, or safety precautions.
@@ -583,11 +594,11 @@ __DATA__
 DISTNAME: Test-Tech^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.14^
+VERSION : 0.15^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.13^
-REVISION: L^
+PREVIOUS_RELEASE: 0.14^
+REVISION: M^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: 
@@ -628,7 +639,7 @@ t/Test/Tech/V001024/*
 t/Test/Tech/V001015/*
 ^
 
-PREREQ_PM: lib/Data/Strify.pm^
+PREREQ_PM: Data::Secs2 => 0.01^
 
 TESTS: t/Test/Tech/Tech.t^
 EXE_FILES:  ^
@@ -819,6 +830,19 @@ Use Archive::TarGzip 0.02 that uses mode 777 for directories instead of 666. Sta
 emails from Unix about untar not being able to change to
 a directory with mod of 666.
 
+\=item Test-Tech-0.15
+
+Changed from using 'Data::Strify' to 'Data::Secs2' for the stringify function.
+'Data::Secs2' is useful for SEMI clients and also provides sorted hash keys
+required for comparing stringifcation of Perl's nested data.
+The 'Data::Secs2' obsoletes 'Data::Strify' which is history. 
+
+Double checked that PREREQ_PM is 'Data::Secs2' which
+fixes Test-Tech-0.14 error in the PREREQ_PM 
+which errorneous used by 'Data/Strify.pm' instead of 'Data::Strify'.
+This should clear complain by Mike Castle <dalgoda@ix.netcom.com> that
+the MakeFile.PL for Test-Tech-0.14 crashes with a divide by zero.
+
 \=back
 
 ^
